@@ -27,6 +27,7 @@
 #include "formlayoutattached.h"
 #include "mnemonicattached.h"
 #include "delegaterecycler.h"
+#include "pagepool.h"
 #include "scenepositionattached.h"
 #include "wheelhandler.h"
 
@@ -34,6 +35,8 @@
 #include <QQmlContext>
 #include <QQuickItem>
 #include <QQuickStyle>
+#include <QGuiApplication>
+#include <QClipboard>
 
 #include "libkirigami/platformtheme.h"
 
@@ -44,6 +47,16 @@ static QString s_selectedStyle;
 #include <qrc_kirigami.cpp>
 #endif
 
+class CopyHelperPrivate : public QObject
+{
+    Q_OBJECT
+    public:
+        Q_INVOKABLE static void copyTextToClipboard(const QString& text)
+        {
+            qGuiApp->clipboard()->setText(text);
+        }
+};
+
 QUrl KirigamiPlugin::componentUrl(const QString &fileName) const
 {
     for (const QString &style : qAsConst(m_stylesFallbackChain)) {
@@ -80,11 +93,11 @@ void KirigamiPlugin::registerTypes(const char *uri)
         m_stylesFallbackChain.prepend(QStringLiteral("org.kde.desktop"));
     }
 #elif defined(Q_OS_ANDROID)
-    if (!m_stylesFallbackChain.contains(QStringLiteral("Material"))) {
+    if (!m_stylesFallbackChain.contains(QLatin1String("Material"))) {
         m_stylesFallbackChain.prepend(QStringLiteral("Material"));
     }
 #else // do we have an iOS specific style?
-    if (!m_stylesFallbackChain.contains(QStringLiteral("Material"))) {
+    if (!m_stylesFallbackChain.contains(QLatin1String("Material"))) {
         m_stylesFallbackChain.prepend(QStringLiteral("Material"));
     }
 #endif
@@ -180,6 +193,7 @@ void KirigamiPlugin::registerTypes(const char *uri)
     qmlRegisterType(componentUrl(QStringLiteral("AboutPage.qml")), uri, 2, 6, "AboutPage");
     qmlRegisterType(componentUrl(QStringLiteral("LinkButton.qml")), uri, 2, 6, "LinkButton");
     qmlRegisterType(componentUrl(QStringLiteral("UrlButton.qml")), uri, 2, 6, "UrlButton");
+    qmlRegisterSingletonType<CopyHelperPrivate>("org.kde.kirigami.private", 2, 6, "CopyHelperPrivate", [] (QQmlEngine*, QJSEngine*) -> QObject* { return new CopyHelperPrivate; });
 
     //2.7
     qmlRegisterType<ColumnView>(uri, 2, 7, "ColumnView");
@@ -193,8 +207,17 @@ void KirigamiPlugin::registerTypes(const char *uri)
     qmlRegisterType<WheelHandler>(uri, 2, 9, "WheelHandler");
     qmlRegisterUncreatableType<KirigamiWheelEvent>(uri, 2, 9, "WheelEvent", QStringLiteral("Cannot create objects of type WheelEvent."));
 
+    //2.10
+    qmlRegisterType(componentUrl(QStringLiteral("ListSectionHeader.qml")), uri, 2, 10, "ListSectionHeader");
+
+    // 2.11
+    qmlRegisterType<PagePool>(uri, 2, 11, "PagePool");
+    qmlRegisterType(componentUrl(QStringLiteral("PagePoolAction.qml")), uri, 2, 11, "PagePoolAction");
+
+    //TODO: remove
+    qmlRegisterType(componentUrl(QStringLiteral("SwipeListItem2.qml")), uri, 2, 11, "SwipeListItem2");
+
     qmlProtectModule(uri, 2);
 }
 
-#include "moc_kirigamiplugin.cpp"
-
+#include "kirigamiplugin.moc"
